# arnie
Python API to compute RNA energetics and do structure prediction across multiple secondary structure packages.

## Documentation
[See our full docs.](https://daslab.github.io/arnie)

## Install
`arnie` is [available on PyPI](https://pypi.org/project/arnie/).

`pip install arnie`

## Repo Organization

`src/arnie`: source code for the arnie package.

`docs`: docsify-based markdown documentation for the arnie package.

`tests`: unit tests 

`notebooks`: example jupyter notebooks with usage.

`scripts`: scripts for processing sequences in batch.

`parameter_files`: dir of various parameter files for packages, put here out of convenience.


(c) 2024 Leland Stanford Jr University
Authors:
Hannah Wayment-Steele